@@ -27,7 +27,6 @@
 #include "response.h"
 #include "tracer.h"
 
-#include "libs/imapparser_p.h"
 #include "imapstreamparser.h"
 #include "shared/akdebug.h"
 #include "shared/akcrash.h"
@@ -44,12 +43,9 @@ AkonadiConnection::AkonadiConnection( quintptr socketDescriptor, QObject *parent
     , m_connectionState( NonAuthenticated )
     , m_backend( 0 )
     , m_selectedConnection( 0 )
-    , m_parser( 0 )
     , m_streamParser( 0 )
 {
     m_identifier.sprintf( "%p", static_cast<void*>( this ) );
-    Tracer::self()->beginConnection( m_identifier, QString() );
-    m_parser = new ImapParser;
 }
 
 DataStore * Akonadi::AkonadiConnection::storageBackend()
@@ -63,8 +59,6 @@ DataStore * Akonadi::AkonadiConnection::storageBackend()
 AkonadiConnection::~AkonadiConnection()
 {
     Tracer::self()->endConnection( m_identifier, QString() );
-
-    delete m_parser;
 }
 
 void AkonadiConnection::run()
@@ -95,9 +89,10 @@ void AkonadiConnection::run()
     connect( m_socket, SIGNAL( disconnected() ),
              this, SLOT( slotDisconnected() ), Qt::DirectConnection );
 
-    writeOut( "* OK Akonadi Almost IMAP Server [PROTOCOL 23]");
+    writeOut( "* OK Akonadi Almost IMAP Server [PROTOCOL 26]");
 
     m_streamParser = new ImapStreamParser( m_socket );
+    m_streamParser->setTracerIdentifier( m_identifier );
     exec();
     delete m_socket;
     m_socket = 0;
@@ -115,7 +110,7 @@ void AkonadiConnection::slotNewData()
   // On Windows, calling readLiteralPart() triggers the readyRead() signal recursively and leads to parse errors
   if ( m_currentHandler )
     return;
-    
+
   while ( m_socket->bytesAvailable() > 0 || !m_streamParser->readRemainingData().isEmpty() ) {
     try {
       const QByteArray tag = m_streamParser->readString();
@@ -123,7 +118,7 @@ void AkonadiConnection::slotNewData()
       if ( tag.isEmpty() && m_streamParser->atCommandEnd() )
         continue;
       const QByteArray command = m_streamParser->readString();
-      Tracer::self()->connectionInput( m_identifier, QString::fromUtf8( tag + " " + command + " " + m_streamParser->readRemainingData() ) );
+      Tracer::self()->connectionInput( m_identifier, QString::fromUtf8( tag + ' ' + command + ' ' + m_streamParser->readRemainingData() ) );
       m_currentHandler = findHandlerForCommand( command );
       assert( m_currentHandler );
       connect( m_currentHandler, SIGNAL( responseAvailable( const Response & ) ),
@@ -134,12 +129,12 @@ void AkonadiConnection::slotNewData()
       m_currentHandler->setTag( tag );
       m_currentHandler->setStreamParser( m_streamParser );
       if ( !m_currentHandler->parseStream() ) {
-        m_streamParser->readUntilCommandEnd(); //just eat the ending newline
+        m_streamParser->skipCurrentCommand();
       }
     } catch ( const Akonadi::HandlerException &e ) {
       m_currentHandler->failureResponse( e.what() );
       try {
-        m_streamParser->readUntilCommandEnd(); //just eat the ending newline
+        m_streamParser->skipCurrentCommand();
       } catch ( ... ) {}
     } catch ( const Akonadi::Exception &e ) {
       if ( m_currentHandler ) {
@@ -147,7 +142,7 @@ void AkonadiConnection::slotNewData()
           + QLatin1String( ": " ) + QString::fromLatin1( e.what()  ) );
       }
       try {
-        m_streamParser->readUntilCommandEnd(); //just eat the ending newline
+        m_streamParser->skipCurrentCommand();
       } catch ( ... ) {}
     } catch ( ... ) {
       akError() << "Unknown exception caught: " << akBacktrace();
@@ -155,7 +150,7 @@ void AkonadiConnection::slotNewData()
         m_currentHandler->failureResponse( "Unknown exception caught" );
       }
       try {
-        m_streamParser->readUntilCommandEnd(); //just eat the ending newline
+        m_streamParser->skipCurrentCommand();
       } catch ( ... ) {}
     }
     delete m_currentHandler;
@@ -262,6 +257,10 @@ void Akonadi::AkonadiConnection::flushStatusMessageQueue()
 
 void AkonadiConnection::setSessionId(const QByteArray &id)
 {
+  m_identifier.sprintf( "%s (%p)", id.data(), static_cast<void*>( this ) );
+  Tracer::self()->beginConnection( m_identifier, QString() );
+  m_streamParser->setTracerIdentifier( m_identifier );
+
   m_sessionId = id;
   storageBackend()->setSessionId( id );
   storageBackend()->notificationCollector()->setSessionId( id );
@@ -292,4 +291,13 @@ bool AkonadiConnection::isOwnerResource(const PimItem& item) const
   return false;
 }
 
+bool AkonadiConnection::isOwnerResource(const Collection &collection) const
+{
+  if ( resourceContext().isValid() )
+    return true;
+  if ( sessionId() == collection.resource().name().toUtf8() )
+    return true;
+  return false;
+}
+
 #include "akonadiconnection.moc"
