@@ -20,10 +20,12 @@
 #ifndef AKONADI_FETCHHELPER_H
 #define AKONADI_FETCHHELPER_H
 
+#include <QtCore/QStack>
+
 #include "scope.h"
 #include "libs/imapset_p.h"
 #include "storage/datastore.h"
-#include <QtCore/QStack>
+#include "storage/itemretriever.h"
 
 namespace Akonadi {
 
@@ -37,10 +39,8 @@ class FetchHelper : public QObject
   Q_OBJECT
 
   public:
-    FetchHelper( const Scope &scope );
-    FetchHelper( const ImapSet &imapSet );
+    FetchHelper( AkonadiConnection *connection, const Scope &scope );
 
-    void setConnection( AkonadiConnection *connection );
     void setStreamParser( ImapStreamParser *parser );
 
     bool parseStream( const QByteArray &responseIdentifier );
@@ -54,21 +54,17 @@ class FetchHelper : public QObject
     void parseCommand( const QByteArray &line );
     void updateItemAccessTime();
     void triggerOnDemandFetch();
-    void buildItemQuery();
-    QueryBuilder buildPartQuery( const QStringList &partList, bool allPayload, bool allAttrs );
-    void retrieveMissingPayloads( const QStringList &payloadList );
+    QSqlQuery buildItemQuery();
+    QSqlQuery buildPartQuery( const QStringList &partList, bool allPayload, bool allAttrs );
+    QSqlQuery buildFlagQuery();
     void parseCommandStream();
     QStack<Collection> ancestorsForItem( Collection::Id parentColId );
 
   private:
-    Scope mScope;
-    ImapSet mSet;
-    bool mUseScope;
-
-    AkonadiConnection *mConnection;
     ImapStreamParser *mStreamParser;
 
-    QueryBuilder mItemQuery;
+    AkonadiConnection *mConnection;
+    Scope mScope;
     QList<QByteArray> mRequestedParts;
     QHash<Collection::Id, QStack<Collection> > mAncestorCache;
     int mAncestorDepth;
@@ -78,6 +74,7 @@ class FetchHelper : public QObject
     bool mSizeRequested;
     bool mMTimeRequested;
     bool mExternalPayloadSupported;
+    bool mRemoteRevisionRequested;
 };
 
 }
