@@ -26,10 +26,14 @@
 #include "storage/entity.h"
 #include "storage/transaction.h"
 #include "handlerhelper.h"
-#include "abstractsearchmanager.h"
+#include "search/searchmanager.h"
 #include "imapstreamparser.h"
+#include "libs/protocol_p.h"
+#include <akdebug.h>
 
 #include <QtCore/QStringList>
+#include <qdbusinterface.h>
+#include <QtDBus/qdbusreply.h>
 
 using namespace Akonadi;
 
@@ -52,32 +56,42 @@ bool SearchPersistent::parseStream()
   DataStore *db = connection()->storageBackend();
   Transaction transaction( db );
 
-  QByteArray queryString = m_streamParser->readString();
+  const QString queryString = m_streamParser->readUtf8String();
   if ( queryString.isEmpty() )
     return failureResponse( "No query specified" );
 
   Collection col;
-  col.setRemoteId( QString::fromUtf8( queryString ) );
+  col.setQueryString( queryString );
+  col.setQueryLanguage( QLatin1String( "SPARQL" ) ); // TODO receive from client
+  col.setRemoteId( queryString ); // ### remove, legacy compat
   col.setParentId( 1 ); // search root
   col.setResourceId( 1 ); // search resource
   col.setName( collectionName );
   if ( !db->appendCollection( col ) )
     return failureResponse( "Unable to create persistent search" );
 
-  if ( !AbstractSearchManager::instance()->addSearch( col ) )
-    return failureResponse( "Unable to add search to search manager" );
+  // work around the fact that we have no clue what might be in there
+  MimeType::List mts = MimeType::retrieveAll();
+  foreach ( const MimeType &mt, mts ) {
+    if ( mt.name() == QLatin1String( "inode/directory" ) )
+      continue;
+    col.addMimeType( mt );
+  }
 
   if ( !transaction.commit() )
     return failureResponse( "Unable to commit transaction" );
 
-  Response response;
-  response.setTag( tag() );
-  response.setSuccess();
-  response.setString( "SEARCH_STORE completed" );
-  emit responseAvailable( response );
+  if ( !SearchManager::instance()->addSearch( col ) )
+    return failureResponse( "Unable to add search to search manager" );
 
-  deleteLater();
-  return true;
+  const QByteArray b = HandlerHelper::collectionToByteArray( col );
+
+  Response colResponse;
+  colResponse.setUntagged();
+  colResponse.setString( b );
+  emit responseAvailable( colResponse );
+
+  return successResponse( "SEARCH_STORE completed" );
 }
 
 #include "searchpersistent.moc"
