@@ -80,8 +80,7 @@ QString HandlerHelper::pathForCollection(const Collection & col)
 
 int HandlerHelper::itemCount(const Collection & col)
 {
-  CountQueryBuilder qb;
-  qb.addTable( PimItem::tableName() );
+  CountQueryBuilder qb( PimItem::tableName() );
   qb.addValueCondition( PimItem::collectionIdColumn(), Query::Equals, col.id() );
   if ( !qb.exec() )
     return -1;
@@ -90,13 +89,12 @@ int HandlerHelper::itemCount(const Collection & col)
 
 int HandlerHelper::itemWithFlagCount(const Collection & col, const QString & flag)
 {
-  CountQueryBuilder qb;
-  qb.addTable( PimItem::tableName() );
-  qb.addTable( Flag::tableName() );
-  qb.addTable( PimItemFlagRelation::tableName() );
+  CountQueryBuilder qb( PimItem::tableName() );
+  qb.addJoin( QueryBuilder::InnerJoin, PimItemFlagRelation::tableName(),
+              PimItem::idFullColumnName(), PimItemFlagRelation::leftFullColumnName() );
+  qb.addJoin( QueryBuilder::InnerJoin, Flag::tableName(),
+              Flag::idFullColumnName(), PimItemFlagRelation::rightFullColumnName() );
   qb.addValueCondition( PimItem::collectionIdFullColumnName(), Query::Equals, col.id() );
-  qb.addColumnCondition( PimItem::idFullColumnName(), Query::Equals, PimItemFlagRelation::leftFullColumnName() );
-  qb.addColumnCondition( Flag::idFullColumnName(), Query::Equals, PimItemFlagRelation::rightFullColumnName() );
   qb.addValueCondition( Flag::nameFullColumnName(), Query::Equals, flag );
   if ( !qb.exec() )
     return -1;
@@ -115,8 +113,7 @@ int HandlerHelper::itemWithoutFlagCount(const Collection & col, const QString &
 
 qint64 HandlerHelper::itemsTotalSize(const Collection & col)
 {
-  QueryBuilder qb;
-  qb.addTable( PimItem::tableName() );
+  QueryBuilder qb( PimItem::tableName() );
   qb.addValueCondition( PimItem::collectionIdColumn(), Query::Equals, col.id() );
   qb.addColumn( QLatin1String("sum(size)") );
 
@@ -192,13 +189,13 @@ QByteArray HandlerHelper::collectionToByteArray( const Collection & col, bool hi
   QByteArray b = QByteArray::number( col.id() ) + ' '
                + QByteArray::number( col.parentId() ) + " (";
 
-  // FIXME: escape " and "\"
-  b += "NAME \"" + col.name() + "\" ";
+  b += "NAME "+ ImapParser::quote( col.name() ) + ' ';
   if ( hidden )
     b+= "MIMETYPE () ";
   else
     b += "MIMETYPE (" + MimeType::joinByName( col.mimeTypes(), QLatin1String( " " ) ).toLatin1() + ") ";
   b += "REMOTEID " + ImapParser::quote( col.remoteId().toUtf8() );
+  b += " REMOTEREVISION " + ImapParser::quote( col.remoteRevision().toUtf8() );
   b += " RESOURCE " + ImapParser::quote( col.resource().name().toUtf8() ) + ' ';
 
   if ( includeStatistics ) {
@@ -207,6 +204,17 @@ QByteArray HandlerHelper::collectionToByteArray( const Collection & col, bool hi
       b += "SIZE " + QByteArray::number( HandlerHelper::itemsTotalSize( col ) ) + ' ';
   }
 
+  if ( !col.queryLanguage().isEmpty() ) {
+    b += AKONADI_PARAM_PERSISTENTSEARCH " ";
+    QList<QByteArray> args;
+    args.append( AKONADI_PARAM_PERSISTENTSEARCH_QUERYLANG );
+    args.append( col.queryLanguage().toLatin1() );
+    args.append( AKONADI_PARAM_PERSISTENTSEARCH_QUERYSTRING );
+    args.append( ImapParser::quote( col.queryString().toUtf8() ) );
+    b += ImapParser::quote( "(" + ImapParser::join( args, " " ) + ")" );
+    b += ' ';
+  }
+
   b += HandlerHelper::cachePolicyToByteArray( col ) + ' ';
   if ( ancestorDepth > 0 )
     b += HandlerHelper::ancestorsToByteArray( ancestorDepth, ancestors ) + ' ';
