@@ -36,7 +36,6 @@ ImapStreamParser::ImapStreamParser( QIODevice *socket ) :
   m_socket = socket;
   m_position = 0;
   m_literalSize = 0;
-  m_continuationSize = 0;
 }
 
 ImapStreamParser::~ImapStreamParser()
@@ -132,9 +131,8 @@ bool ImapStreamParser::hasLiteral()
     if ( m_position < m_data.length() && m_data[m_position] == '\n' )
       ++m_position;
 
-    m_continuationSize = qMin(m_position + m_literalSize - m_data.length(), (qint64)4096);
-    if (m_continuationSize >= 0)
-      sendContinuationResponse();
+    if ( m_literalSize >= 0 )
+      sendContinuationResponse( m_literalSize );
     return true;
   } else
   {
@@ -745,17 +743,34 @@ QByteArray ImapStreamParser::readUntilCommandEnd()
   return result;
 }
 
-void ImapStreamParser::sendContinuationResponse()
+void ImapStreamParser::skipCurrentCommand()
 {
-  QByteArray block = "+ Ready for literal data (expecting "
-                   + QByteArray::number(  m_continuationSize ) + " bytes)\r\n";
+  int i = m_position;
+  Q_FOREVER {
+    if ( !waitForMoreData( m_data.length() <= i ) ) {
+      m_position = i;
+      throw ImapParserException("Unable to read more data");
+    }
+    if ( m_data[i] == '\n'  || m_data[i] == '\r' )
+      break; //command end
+    ++i;
+  }
+  m_position = i + 1;
+  // We'd better empty m_data from time to time before it grows out of control
+  if ( !m_peeking ) {
+    m_data = m_data.right(m_data.size()-m_position);
+    m_position = 0;
+  }
+}
+
+void ImapStreamParser::sendContinuationResponse( qint64 size )
+{
+  const QByteArray block = "+ Ready for literal data (expecting "
+                   + QByteArray::number( size ) + " bytes)\r\n";
   m_socket->write(block);
   m_socket->waitForBytesWritten(30000);
 
-  QString identifier;
-  identifier.sprintf( "%p", static_cast<void*>( this ) );
-  Tracer::self()->connectionOutput( identifier, QString::fromUtf8( block ) );
-
+  Tracer::self()->connectionOutput( m_tracerId, QString::fromUtf8( block ) );
 }
 
 void ImapStreamParser::insertData( const QByteArray& data)
@@ -767,3 +782,8 @@ void ImapStreamParser::appendData( const QByteArray& data)
 {
   m_data = m_data + data;
 }
+
+void ImapStreamParser::setTracerIdentifier(const QString& id)
+{
+  m_tracerId = id;
+}
