@@ -20,9 +20,9 @@
 
 #include <QtCore/QTextStream>
 
-using namespace Akonadi::Server;
+using namespace Akonadi;
 
-static const char *s_resultCodeStrings[] = {
+static const char* s_resultCodeStrings[] = {
     "OK", "NO", "BAD", "BYE", ""
 };
 
@@ -32,6 +32,7 @@ Response::Response()
 {
 }
 
+
 Response::~Response()
 {
 }
@@ -48,52 +49,53 @@ QByteArray Response::asString() const
     return b;
 }
 
-Response::ResultCode Response::resultCode() const
-{
-  return m_resultCode;
-}
-
-void Response::setSuccess()
+void Response::setSuccess( )
 {
     m_resultCode = Response::OK;
 }
 
-void Response::setFailure()
+void Response::setFailure( )
 {
     m_resultCode = Response::NO;
 }
 
-void Response::setError()
+void Response::setError( )
 {
     m_resultCode = Response::BAD;
 }
 
-void Response::setTag( const QByteArray &tag )
+void Response::setTag( const QByteArray& tag )
 {
     m_tag = tag;
 }
 
-void Response::setUntagged()
+void Response::setUntagged( )
 {
-    m_tag = QByteArray( 1, '*' );
+    m_tag = QByteArray(1, '*');
 }
 
-void Response::setContinuation()
+void Response::setContinuation( )
 {
-    m_tag = QByteArray( 1, '+' );
+    m_tag = QByteArray(1, '+');
 }
 
-void Response::setString( const QByteArray &string )
+void Response::setString( const QByteArray & string )
 {
     m_responseString = string;
 }
 
-void Response::setString( const char *string )
+void Akonadi::Response::setString( const QString & string )
+{
+    m_responseString = string.toLatin1();
+}
+
+
+void Akonadi::Response::setString( const char *string )
 {
     m_responseString = QByteArray( string );
 }
 
-void Response::setBye()
+void Response::setBye( )
 {
     m_resultCode = Response::BYE;
 }
