@@ -111,7 +111,7 @@ bool DbInitializer::checkTable( const QDomElement &element )
 
       // TODO: we need a nicer way for this...
       // special cases for sqlite
-      if ( mDatabase.driverName().startsWith( QLatin1String("QSQLITE") ) ) {
+      if ( mDatabase.driverName().startsWith( QLatin1String( "QSQLITE" ) ) ) {
         if ( props.contains(QLatin1String("PRIMARY KEY")) && entry.second == QLatin1String("BIGINT") )
             entry.second = QLatin1String("INTEGER");
         if ( props.contains(QLatin1String("BINARY")) && !props.contains(QLatin1String("COLLATE BINARY")) )
@@ -130,8 +130,10 @@ bool DbInitializer::checkTable( const QDomElement &element )
           entry.second.replace(QLatin1String("CHAR"), QLatin1String("VARCHAR"));
         if ( entry.second.contains( QLatin1String( "BINARY" ) ) )
           entry.second.remove( QLatin1String( "BINARY" ) );
-        if ( entry.second.contains(QLatin1String("character set utf8 collate utf8_bin")) )
+        if ( entry.second.contains(QLatin1String("character set utf8 collate utf8_bin")) ) {
           entry.second.remove(QLatin1String("character set utf8 collate utf8_bin"));
+          entry.second.replace(QLatin1String("VARCHAR(255)"), QLatin1String("BYTEA"));
+        }
       }
       // special cases for MySQL
       else if ( mDatabase.driverName().startsWith( QLatin1String("QMYSQL") ) ) {
@@ -147,15 +149,19 @@ bool DbInitializer::checkTable( const QDomElement &element )
         const QString refStmt = QString::fromLatin1( " REFERENCES %1Table(%2) ON DELETE CASCADE ON UPDATE CASCADE" )
           .arg( columnElement.attribute( QLatin1String( "refTable" ) ) )
           .arg( columnElement.attribute( QLatin1String( "refColumn" ) ) );
-        if ( !mDatabase.driverName().startsWith( QLatin1String("QSQLITE") ) )
+        if ( !mDatabase.driverName().startsWith( QLatin1String( "QSQLITE" ) ) )
           entry.second += refStmt;
       }
 
       columnsList.append( entry );
     } else if ( columnElement.tagName() == QLatin1String( "data" ) ) {
       QString values = columnElement.attribute( QLatin1String("values") );
-      if ( mDatabase.driverName().startsWith( QLatin1String("QMYSQL") ) )
+      if ( mDatabase.driverName().startsWith( QLatin1String("QMYSQL") ) ) {
         values.replace( QLatin1String("\\"), QLatin1String("\\\\") );
+      } else if ( mDatabase.driverName().startsWith( QLatin1String( "QSQLITE" ) ) ) {
+        values.replace( QLatin1String("true"), QLatin1String( "1" ) );
+        values.replace( QLatin1String("false"), QLatin1String( "0" ) );
+      }
       QString statement = QString::fromLatin1( "INSERT INTO %1 (%2) VALUES (%3)" )
           .arg( tableName )
           .arg( columnElement.attribute( QLatin1String("columns") ) )
@@ -187,7 +193,13 @@ bool DbInitializer::checkTable( const QDomElement &element )
     if( element.hasAttribute( QLatin1String("properties") ) )
       columns.append( QLatin1String(", ") + element.attribute( QLatin1String("properties") ) );
 
-    const QString statement = QString::fromLatin1( "CREATE TABLE %1 (%2);" ).arg( tableName, columns );
+    QString tableProperties;
+    if ( mDatabase.driverName().startsWith( QLatin1String("QMYSQL") ) ) {
+      tableProperties += QLatin1String( " COLLATE=utf8_general_ci" );
+      tableProperties += QLatin1String( " DEFAULT CHARSET=utf8" );
+    }
+
+    const QString statement = QString::fromLatin1( "CREATE TABLE %1 (%2) %3;" ).arg( tableName, columns, tableProperties );
     qDebug() << statement;
 
     if ( !query.exec( statement ) ) {
@@ -370,7 +382,7 @@ bool DbInitializer::hasIndex(const QString & tableName, const QString & indexNam
     statement  = QLatin1String( "SELECT indexname FROM pg_catalog.pg_indexes" );
     statement += QString::fromLatin1( " WHERE tablename ilike '%1'" ).arg( tableName );
     statement += QString::fromLatin1( " AND  indexname ilike '%1';" ).arg( indexName );
-  } else if ( mDatabase.driverName() == QLatin1String("QSQLITE") ) {
+  } else if ( mDatabase.driverName().startsWith( QLatin1String( "QSQLITE" ) ) ) {
     statement  = QString::fromLatin1( "SELECT * FROM sqlite_master WHERE type='index' AND tbl_name='%1' AND name='%2';" ).arg( tableName ).arg( indexName );
   } else {
     qFatal( "Implement index support for your database!" );
