@@ -35,7 +35,11 @@ using namespace Akonadi;
 ItemRetrievalManager* ItemRetrievalManager::sInstance = 0;
 
 ItemRetrievalManager::ItemRetrievalManager( QObject *parent ) :
-  QObject( parent )
+  QObject( parent ),
+  mDBusConnection(
+      QDBusConnection::connectToBus(
+          QDBusConnection::SessionBus,
+          QString::fromLatin1("AkonadiServerItemRetrievalManager") ) )
 {
   // make sure we are created from the retrieval thread and only once
   Q_ASSERT( QThread::currentThread() != QCoreApplication::instance()->thread() );
@@ -45,12 +49,13 @@ ItemRetrievalManager::ItemRetrievalManager( QObject *parent ) :
   mLock = new QReadWriteLock();
   mWaitCondition = new QWaitCondition();
 
-  connect( QDBusConnection::sessionBus().interface(), SIGNAL(serviceOwnerChanged(QString,QString,QString)),
+
+  connect( mDBusConnection.interface(), SIGNAL(serviceOwnerChanged(QString,QString,QString)),
            this, SLOT(serviceOwnerChanged(QString,QString,QString)) );
   connect( this, SIGNAL(requestAdded()), this, SLOT(processRequest()), Qt::QueuedConnection );
   connect( this, SIGNAL(syncCollection(QString,qint64)), this, SLOT(triggerCollectionSync(QString,qint64)), Qt::QueuedConnection );
-  connect( this, SIGNAL( syncResource( const QString& ) ),
-           this, SLOT( triggerResourceSync( const QString& ) ), Qt::QueuedConnection );
+  connect( this, SIGNAL( syncCollectionTree( const QString& ) ),
+           this, SLOT( triggerCollectionTreeSync( const QString& ) ), Qt::QueuedConnection );
 }
 
 ItemRetrievalManager::~ItemRetrievalManager()
@@ -92,7 +97,7 @@ OrgFreedesktopAkonadiResourceInterface* ItemRetrievalManager::resourceInterface(
 
   delete iface;
   iface = new OrgFreedesktopAkonadiResourceInterface( QLatin1String("org.freedesktop.Akonadi.Resource.") + id,
-                                                      QLatin1String("/"), QDBusConnection::sessionBus(), this );
+                                                      QLatin1String("/"), mDBusConnection, this );
   if ( !iface || !iface->isValid() ) {
     qDebug() << QString::fromLatin1( "Cannot connect to agent instance with identifier '%1', error message: '%2'" )
                                     .arg( id, iface ? iface->lastError().message() : QString() );
@@ -214,7 +219,7 @@ void ItemRetrievalManager::requestCollectionSync( const Collection& collection )
   // if the collection is a resource collection we trigger a synchronization
   // of the collection hierarchy as well
   if ( collection.parentId() == 0 )
-    emit syncResource( collection.resource().name() );
+    emit syncCollectionTree( collection.resource().name() );
 
   emit syncCollection( collection.resource().name(), collection.id() );
 }
@@ -226,11 +231,11 @@ void ItemRetrievalManager::triggerCollectionSync(const QString& resource, qint64
     interface->synchronizeCollection( colId );
 }
 
-void ItemRetrievalManager::triggerResourceSync( const QString& resource )
+void ItemRetrievalManager::triggerCollectionTreeSync( const QString& resource )
 {
   OrgFreedesktopAkonadiResourceInterface *interface = resourceInterface( resource );
   if ( interface )
-    interface->synchronize();
+    interface->synchronizeCollectionTree();
 }
 
 #include "itemretrievalmanager.moc"
